.. _c_sock_module:

-------------------------
:mod:`ginsfsm.c_sock`
-------------------------

.. automodule:: ginsfsm.c_sock

.. autoclass:: GSock
    :members: start_up, mt_connect, get_next_dst, mt_drop, mt_send_data

